---
name: Bug report
about: Report an error that you've encountered.
labels: 'bug'
---
### Environment information

* `ape` and plugin versions:

```
$ ape --version
# ...copy and paste result of above command here...

$ ape plugins list
# ...copy and paste result of above command here...
```

* Python Version: x.x.x
* OS: macOS/linux/win

### What went wrong?

Please include information like:

* what command you ran
* the code that caused the failure (see [this link](https://help.github.com/articles/basic-writing-and-formatting-syntax/) for help with formatting code)
* full output of the error you received

### How can it be fixed?

Fill this in if you have ideas on how the bug could be fixed.
